@@ -9,7 +9,8 @@ import matplotlib.pyplot as plt
 #         r'D:\Pycharm\PyThat\examples\Spot_characterization_on_Thorlabs_R1DS2N_across_slit_hi_res.h5',
 #         r"D:\Pycharm\PyThat\examples\100mm_scan_radius - Kopie.h5",
 #         r'D:\Pycharm\PyThat\examples\M486 Dispersion 40 mT.h5']
-path = r'D:\Pycharm\PyThat\examples\M486 Dispersion 40 mT.h5'
+# path = r'D:\Pycharm\PyThat\examples\M486 Dispersion 40 mT.h5'
+path = r'D:\Pycharm\PyThat\examples\single.h5'
 # index = (2, 1)
 # index = (3,0)
 # Optional: If the index is known beforehand, it can be specified here. Otherwise the user will be asked to choose.
@@ -34,8 +35,11 @@ path = r'D:\Pycharm\PyThat\examples\M486 Dispersion 40 mT.h5'
 #     plt.show()
 
 
-data = MeasurementTree(path, index=True, override=False)
+data = MeasurementTree(path, index=False, override=True)
 print(data.tree_string)
+print(data.definition)
+print(data.labbook)
+print(data.logs)
 print(data.dataset)
 exit()
 
